#!/bin/bash

################################################################################
# Params:
#	$1 maximum memory allocation pool for a Java Virtual Machine (JVM)'s
#   $2 timeout in seconds
#   $3 fqe properties file
#	$4 rdfvs properties file
#	$5 (alert) email to address
#	$6 queries to execute range from
#   $7 queries to execute range to
#	$8 postgresql instance data directory
################################################################################
postgresql_data_dir=$8

################################################################################
# Asserts the number of parameters given is correct.
################################################################################
if [ "$#" -ne 8 ]; then
	echo "Illegal number of parameters."
	echo "Parameters:"
	echo "   * Maximum memory allocation pool for a Java Virtual Machine (JVM)'s"
	echo "   * Timeout in seconds"
	echo "   * fqe properties file"
	echo "   * rdfvs properties file"
	echo "   * Email to address for alert emails"
	echo "   * Queries to execute range from"
	echo "   * Queries to execute range to"
	echo "   * postgresql instance data directory"
	echo "Use example: fqe_postgres \"12288m\" 3600 /path/to/fqe.properties /path/to/rdfvs.properties \"test@localhost.com\" 1 28 /path/to/postgresql/data"
	exit 1
fi


################################################################################
# Forces Postgresql server stop and start.
# Uses:
#	$postgresql_data_dir
# Requires user permissions.
################################################################################
restart() {
	/data/postgres/bin/pg_ctl stop -D $postgresql_data_dir -m immediate
	/data/postgres/bin/pg_ctl start -D $postgresql_data_dir
}

. fqe.sh

echo_parameters
echo "Postgresql instance data directory: ${postgresql_data_dir}"
execute_all_with_timeout